rm(list=ls(all=TRUE))
library(dplyr)
library(ggplot2)

#==============================================#
# Read in estimates, calculate 95% ci, stack
#==============================================#

p14 <- read.csv("Data/P2014_Estimates_for_R.csv", header=TRUE, stringsAsFactors=FALSE, strip.white=TRUE)
p14$lower <- with(p14, b - 1.96*se)
p14$upper <- with(p14, b + 1.96*se)

ms <- read.csv("Data/MS_Estimates_for_R.csv", header=TRUE, stringsAsFactors=FALSE, strip.white=TRUE)
ms$lower <- with(ms, b - 1.96*se)
ms$upper <- with(ms, b + 1.96*se)

ms$referent <- "self"
p14$referent <- "group"

head(ms)
head(p14)
df <- rbind(ms, p14)
head(df)

df$xlab <- rep(NA, nrow(df))
df$xlab <- with(df, ifelse(referent == "group" & var == "pos", "Effect of\nPositively\nFramed Appeal\nversus Placebo", xlab))
df$xlab <- with(df, ifelse(referent == "group" & var == "neg", "Effect of\nNegatively\nFramed Appeal\nversus Placebo", xlab))
df$xlab <- with(df, ifelse(referent == "group" & var == "diff", "Difference\n(Positive Minus\nNegative Framing\nEffects)", xlab))
df$xlab <- with(df, ifelse(referent == "self" & var == "pos", "Effect of\nPositively\nFramed Appeal\nversus Control", xlab))
df$xlab <- with(df, ifelse(referent == "self" & var == "neg", "Effect of\nNegatively\nFramed Appeal\nversus Control", xlab))
df$xlab <- with(df, ifelse(referent == "self" & var == "diff", "Difference\n(Positive Minus\nNegative Framing\nEffects)", xlab))

df$xlab <- factor(df$xlab, levels=c("Effect of\nPositively\nFramed Appeal\nversus Placebo",
                                    "Effect of\nPositively\nFramed Appeal\nversus Control",
                                    "Effect of\nNegatively\nFramed Appeal\nversus Placebo",
                                    "Effect of\nNegatively\nFramed Appeal\nversus Control",
                                    "Difference\n(Positive Minus\nNegative Framing\nEffects)"))
head(df)


df$title <- ifelse(df$referent == "group",
                   "Study 1: Experiment with Group Referent\n2014 Primary Election among Contacted Ever-Voters in MI, MO, TN\nPlacebo Group Mean Turnout Rate = 32.2%",
                   "Study 2: Experiment with Self Referent\n2014 General Election among Intermittent Voters in MS\nControl Group Mean Turnout Rate = 26.9%")
df$subtitle <- ifelse(df$referent == "group",
                      "2014 Primary Election among Contacted Ever-Voters in MI, MO, TN\nPlacebo Group Mean Turnout Rate = 32.2%",
                      "2014 General Election among Intermittent Voters in MS\nControl Group Mean Turnout Rate = 26.9%")

df <- df %>%
  mutate( b = b * 100,
          se = se * 100,
          lower = lower * 100,
          upper = upper * 100)

ggplot(df, aes(x=xlab, y=b)) +
  geom_point(size=3) +
  geom_errorbar(aes(ymin=lower, ymax=upper), width=.2) +
  facet_wrap(~title, scales="free") +
  coord_cartesian(ylim=c(-5, 5)) +
  geom_hline(yintercept = 0, lty = 2) +
  ylab("Estimate (percentage points)") +
  xlab("") +
  scale_y_continuous(breaks=seq(-5, 5, 1), labels=seq(-5, 5, 1)) +
  theme_bw()
ggsave("Figures/Figure1.pdf", width=12, height=5)


