/*=======================================
 2014 PRIMARIES PHONE EXPERIMENT 
	ANALYSIS FILE
 =======================================*/
// Make sure directory is set so files can be properly erased
cd "C:\Users\wujen\Dropbox (Personal)\S_WuHuber\RATasks\archives to check\_To Publish\51 Public Files"
* Load data
use "Data/Data_2014Primary_Exp.dta", clear
numlabel, remove

* Define macro storing list of covariates
global stvars d_st_MO d_st_TN 
global covs d_electiondayage d_electiondayage_miss d_gender_male d_gender_unknown d_race_black d_race_latino d_race_miss d_race_other d_yearssincereg d_yearssincereg_miss d_genvotes d_primvotes d_specvotes

* Define IPWS (by strata: unique combinations of state, dist type, past vote history)
*numerator
preserve
contract strata t_ppn, freq(freq_n)
save "ipw_numerator.dta", replace
restore
*denominators
preserve
contract strata, freq(freq_d)
save "ipw_denominator.dta", replace
restore
*construct weights
preserve
clear
use "ipw_numerator.dta", clear
merge m:1 strata using "ipw_denominator.dta"
gen ipw = 1/(freq_n / freq_d)
list, t
keep strata t_ppn ipw
list, t
save "ipw.dta", replace
restore
cap erase "ipw_numerator.dta"
cap erase "ipw_denominator.dta"
merge m:1 strata t_ppn using "ipw.dta"
drop _merge
cap erase "ipw.dta"


* Analysis focuses on all ever voters who are successfully contacted
* Create flag =1 if subject is in the analysis sample
tab strata, m
gen aev = 0
replace aev = 1 if pass_screener == 1 & (strata_sum != 1 & strata_sum != 2)

* Check Ns
tab1 aev, m

replace pass_screener = 0 if pass_screener == .

/*---------------------------------------------------------- 
 BY BLOCK, TREATMENT ASSIGNMENT RATE FOR ORIGINAL SAMPLE AND CONDITIONING ON CONTACT
 ----------------------------------------------------------*/

tabout strata t_ppn if (strata_sum != 1 & strata_sum != 2) ///
	using "Tables/Table_A1b.out", ///
	cells(freq row) f(0c 2c) clab(N %) replace

tabout strata t_ppn if (strata_sum != 1 & strata_sum != 2) & pass_screener == 1 ///
	using "Tables/Table_A1a.out", ///
	cells(freq row) f(0c 2c) clab(N %) replace
	
* LOGIT ESTIMATES

logit pass_screener i.t_ppn if (strata_sum != 1 & strata_sum != 2) 
outreg2 using "Tables/Table_A6.out", replace label  ctitle("Without Stratum FE") ///
	dec(3) aster(se) addstat("LR Test Chi-Square", e(chi2), "LR Test p-value", e(p)) 

logit pass_screener i.t_ppn i.strata if (strata_sum != 1 & strata_sum != 2) 
testparm i.t_ppn
local c2 = round(r(chi2), 0.01)
local pv = round(r(p), 0.01)
outreg2 using "Tables/Table_A6.out", append label ctitle("With Stratum FE") ///
	dec(3) aster(se) addstat("LR Test Chi-Square", `c2', "LR Test p-value", `pv') 
	

* CONTACT RATE BY ARM, BY BLOCK
//************************************************************ NOTE: This creates Table A7
/*
levelsof strata if (strata_sum != 1 & strata_sum != 2), local(strataval)
foreach s in `strataval' {
tabout pass_screener treat if (strata_sum != 1 & strata_sum != 2) & strata == `s' ///
using "Tables/P2014_ContactRateByArmByBlock_Stratum`s'.out", ///
cells(col) f(2c) clab(%) replace
}
*/

/*---------------------------------------------------------- 
 N BY TREATMENT ARM AND BY STATE, BY SAMPLE DEFINITION
 ----------------------------------------------------------*/

tabout t_ppn vf_state if aev==1 using "Tables/Table_A3.out", cells(freq col) f(0c 2c) clab(N Percent) replace

/*---------------------------------------------------------- 
 RANDOMIZATION CHECKS, BY SAMPLE DEFINITION
 ----------------------------------------------------------*/

mlogit t_ppn $stvars $covs if aev==1, base(0)
outreg2 using "Tables/Table_A4.out", replace keep($stvars $covs) label ///
	dec(3) aster(se) addstat("LR Test Chi-Square", e(chi2), "LR Test p-value", e(p)) 

/*---------------------------------------------------------- 
 BALANCE TABLES, BY SAMPLE DEFINITION
 ----------------------------------------------------------*/

global stvarsBT d_st_MI d_st_MO d_st_TN 


forv z = 0(1)2 {

	if `z' == 0 {
		local zlab = "Placebo"
	}
	else if `z' == 1 {
		local zlab = "Positive,Descriptive,Norm"
	}
	else if `z' == 2 {
		local zlab = "Negative,Descriptive,Norm"
	}

	local clabel = "`zlab'"

	if (`z'==0) {
		outsum $stvarsBT $covs if aev==1 & t_ppn==`z' [aweight=ipw] using "Tables/Table_A5.out" , bracket ctitle("`clabel'") nonotes addnote("Cells contain weighted means and weighted standard deviations in brackets.")  replace
	}
	else {
		outsum $stvarsBT $covs if aev==1 & t_ppn==`z' [aweight=ipw] using "Tables/Table_A5.out" , bracket ctitle("`clabel'") append
	}
}



/*---------------------------------------------------------- 
 ESTIMATE TREATMENT EFFECTS
 ----------------------------------------------------------*/
* Define state-by-covariate interactions
foreach st in $stvars {
foreach v in $covs {
	gen Z_`st'_`v' = `st' * `v'
	qui sum Z_`st'_`v' if aev==1
	if r(sd)==0 | r(sd)==. {
		drop Z_`st'_`v'
	}
}
}

* Define addstat row labels
local diffestlab = "Estimated Diff. in Mean Effects: Positive - Negative Norms"
local diffselab = "Estimated SE, Diff. in Mean Effects: Positive - Negative Norms"
local diffplab = "P-Value: Null Hypothesis that Diff. in Mean Effects of Positive and Negative Norms is Zero"

* Code to capture estimates (cov adjusted w/ weighting) to plot as a figure
capture erase "Data/P2014_Estimates.dta"
tempname tempfile
postfile `tempfile' b_pos se_pos b_neg se_neg b_diff se_diff using "Data/P2014_Estimates.dta"

* Covariate adjusted estimates, weighted
reg voted_2014_primary t_posnorms t_negnorms $covs $stvars Z_* if aev==1 [aweight=ipw], robust
qui sum voted_2014_primary [aweight=ipw] if e(sample) & t_ppn==0
local p_mean = r(mean)
di `p_mean'
lincom t_posnorms - t_negnorms
local diff_est = r(estimate)
local diff_se = r(se)
local diff_tstat = r(estimate) / r(se)
local diff_p = 2*ttail(r(df), abs(r(estimate)/r(se)))
* Save output

outreg2 using "Tables/Table_A2.out", replace dec(3) label keep(t_posnorms t_negnorms) ctitle("Weighted and,with Covariates") ///
	addstat("Placebo Group Mean Turnout", `p_mean', "`diffestlab'", `diff_est', "`diffselab'", `diff_se', "`diffplab'", `diff_p') ///
	addtext("Weighted?", Y, "With Covariates?", Y, "With State Fixed Effects?", Y, "With State-by-Covariate Interactions?", Y)

* Save estimates
post `tempfile' (_b[t_posnorms]) (_se[t_posnorms]) (_b[t_negnorms]) (_se[t_negnorms]) (`diff_est') (`diff_se')
postclose `tempfile'	
	
* Unadjusted estimates, weighted
reg voted_2014_primary t_posnorms t_negnorms if aev==1 [aweight=ipw], robust
qui sum voted_2014_primary [aweight=ipw] if e(sample) & t_ppn==0
local p_mean = r(mean)
di `p_mean'
lincom t_posnorms - t_negnorms
local diff_est = r(estimate)
local diff_se = r(se)
local diff_tstat = r(estimate) / r(se)
local diff_p = 2*ttail(r(df), abs(r(estimate)/r(se)))
* Save output
outreg2 using "Tables/Table_A2.out", append dec(3) label keep(t_posnorms t_negnorms) ctitle("Weighted and,without Covariates") ///
	addstat("Placebo Group Mean Turnout", `p_mean', "`diffestlab'", `diff_est', "`diffselab'", `diff_se', "`diffplab'", `diff_p') ///
	addtext("Weighted?", Y, "With Covariates?", N, "With State Fixed Effects?", N, "With State-by-Covariate Interactions?", N)

* Covariate adjusted estimates, unweighted
reg voted_2014_primary t_posnorms t_negnorms $covs $stvars Z_* if aev==1, robust
qui sum voted_2014_primary if e(sample) & t_ppn==0
local p_mean = r(mean)
di `p_mean'
lincom t_posnorms - t_negnorms
local diff_est = r(estimate)
local diff_se = r(se)
local diff_tstat = r(estimate) / r(se)
local diff_p = 2*ttail(r(df), abs(r(estimate)/r(se)))
* Save output
outreg2 using "Tables/Table_A2.out", append dec(3) label keep(t_posnorms t_negnorms) ctitle("Not Weighted and,with Covariates") ///
	addstat("Placebo Group Mean Turnout", `p_mean', "`diffestlab'", `diff_est', "`diffselab'", `diff_se', "`diffplab'", `diff_p') ///
	addtext("Weighted?", N, "With Covariates?", Y, "With State Fixed Effects?", Y, "With State-by-Covariate Interactions?", Y)

* Unadjusted estimates, unweighted
reg voted_2014_primary t_posnorms t_negnorms if aev==1, robust
qui sum voted_2014_primary if e(sample) & t_ppn==0
local p_mean = r(mean)
di `p_mean'
lincom t_posnorms - t_negnorms
local diff_est = r(estimate)
local diff_se = r(se)
local diff_tstat = r(estimate) / r(se)
local diff_p = 2*ttail(r(df), abs(r(estimate)/r(se)))
* Save output
outreg2 using "Tables/Table_A2.out", append dec(3) label keep(t_posnorms t_negnorms) ctitle("Not Weighted and,without Covariates") ///
	addstat("Placebo Group Mean Turnout", `p_mean', "`diffestlab'", `diff_est', "`diffselab'", `diff_se', "`diffplab'", `diff_p') ///
	addtext("Weighted?", N, "With Covariates?", N, "With State Fixed Effects?", N, "With State-by-Covariate Interactions?", N)
	
drop Z_*


/*---------------------------------------------------------- 
 PREP DATA TO PLOT IN R
 ----------------------------------------------------------*/
 
use "Data/P2014_Estimates.dta", clear
gen id = _n
reshape long b_ se_ , i(id) j(var) s
rename b_ b
rename se_ se
gen qi = 0
replace qi = 1 if var == "pos"
replace qi = 2 if var == "neg"
replace qi = 3 if var == "diff"
drop id
* Save data
compress
outsheet using "Data/P2014_Estimates_for_R.csv", replace comma
erase "Data/P2014_Estimates.dta"
